SystemOrganization addCategory: #'SeasideFAQ-Model'!
SystemOrganization addCategory: #'SeasideFAQ-Tests'!
SystemOrganization addCategory: #'SeasideFAQ-Presentation'!

TestCase subclass: #WAFAQTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideFAQ-Tests'!

!WAFAQTests methodsFor: 'resources' stamp: 'mb 8/18/2006 15:26'!
repository
	^WAFAQRepository default! !

!WAFAQTests methodsFor: 'testing' stamp: 'mb 8/18/2006 16:26'!
testRepositoryContents
	| faqs |
	faqs := self repository contents.
	self assert: (faqs isKindOf: OrderedCollection).
	faqs do:
		[:each |
		self assert: (each isKindOf: Association).
		self assert: (each key isString).
		self assert: (each value isKindOf: SortedCollection).
		each value do:
			[:faq |
			self assert: faq class == WAFrequentlyAskedQuestion.
			self shouldnt: [faq isHtml. faq isLink. faq isText] raise: Error.
			self assert: (faq isHtml isKindOf: Boolean).
			self assert: (faq isText isKindOf: Boolean).
			self assert: (faq isLink isKindOf: Boolean).
			self assert: faq id isInteger.
			self assert: faq question isString.
			self assert: faq response isString.
			self assert: faq title isString.
			self assert: faq type isSymbol.



			]

]! !

WAComponent subclass: #WAFAQ
	instanceVariableNames: 'currentCategory'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideFAQ-Presentation'!

WAFAQ subclass: #WAFAQResponse
	instanceVariableNames: 'faq'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideFAQ-Presentation'!

!WAFAQResponse class methodsFor: 'instance creation' stamp: 'mb 8/18/2006 14:08'!
for: faq
	^self new faq: faq! !

!WAFAQResponse methodsFor: 'accessing' stamp: 'mb 8/18/2006 14:16'!
faq
	^ faq! !

!WAFAQResponse methodsFor: 'accessing' stamp: 'mb 8/18/2006 14:16'!
faq: anObject
	faq := anObject! !

!WAFAQResponse methodsFor: 'rendering' stamp: 'mb 8/18/2006 16:57'!
renderContentOn: html
	html heading: faq title level: 3.
	(html div)
		style: 'text-align: left';
		style: 'margin: 2em';
		with:
			[faq isHtml ifTrue:
				[html html: faq response]
			ifFalse:
				[html withLineBreaks: faq response]].
	html div id: #spacer; with: ''.
	html form:
		[(html submitButton)
			callback: [self answer];
			text: 'Close'].! !

!WAFAQ class methodsFor: 'documentation' stamp: 'mb 8/18/2006 12:23'!
description
	^'Frequently asked questions'! !

!WAFAQ class methodsFor: 'class initialization' stamp: 'mb 8/18/2006 14:12'!
initialize
	| app |
	app := self registerAsApplication: 'faq'.
	app libraries add: SULibrary! !

!WAFAQ methodsFor: 'actions' stamp: 'mb 8/18/2006 14:07'!
displayResponseFor: faq
	self lightbox: (WAFAQResponse for: faq)
! !

!WAFAQ methodsFor: 'rendering' stamp: 'mb 8/18/2006 14:02'!
renderCategory: cat on: html

	| optionalPlural text |
	cat value size = 0 ifTrue:
		[html text: cat key , ' (no item)']
	ifFalse:
		[optionalPlural := cat value size > 1 ifTrue: ['s'] ifFalse: [''].
		text := '(' , cat value size printString , ' item' , optionalPlural , ')'.
		currentCategory = cat key ifTrue:
			[html text: cat key; space; text: text.
			self renderCurrent: cat on: html]
		ifFalse:
			[(html anchor)
				callback: [currentCategory := cat key];
				text: cat key.
			html space.
			html text: text]
		]! !

!WAFAQ methodsFor: 'rendering' stamp: 'mb 8/18/2006 13:47'!
renderContentOn: html

	self renderTopOn: html.
	html heading: 'Frequently asked questions'.
	html orderedList:
		[self repository contents do:
			[:cat |
			html listItem: [self renderCategory: cat on: html]]]
! !

!WAFAQ methodsFor: 'rendering' stamp: 'mb 8/18/2006 14:01'!
renderCurrent: category on: html
	html orderedList:
		[category value do:
			[:faq |
			html listItem: [self renderQuestionAt: faq on: html]]].
! !

!WAFAQ methodsFor: 'rendering' stamp: 'mb 8/18/2006 12:25'!
rendererClass
	^WARenderCanvas! !

!WAFAQ methodsFor: 'rendering' stamp: 'mb 8/18/2006 13:49'!
renderQuestionAt: faq on: html

	faq isLink ifTrue:
			[(html anchor)
				url: faq response;
				text: faq question]
		ifFalse:
			[(html anchor)
				callback: [self displayResponseFor: faq];
				text: faq question]! !

!WAFAQ methodsFor: 'rendering' stamp: 'mb 8/18/2006 12:27'!
renderTopOn: html
	html image
		fileName: 'seaside-top.jpg';
		mimeType: 'image/jpeg';
		document: SeasidePlatformSupport seasideBanner
! !

!WAFAQ methodsFor: 'model' stamp: 'mb 8/18/2006 15:25'!
repository
	^WAFAQRepository default! !

!WAFAQ methodsFor: 'css' stamp: 'mb 8/18/2006 14:22'!
style
	^'
body {
	font-family: Tahoma, Arial;
	font-size: 80%
}
div#spacer {
	height: 5em;
}
div#lightbox {
	background: white;
	border: 1px solid #0000e8;
	padding: 2em;
	width: 50em;
	text-align: center;
}
div#overlay {
	background-color: black;
	filter: alpha(opacity=30);
	-moz-opacity: 0.3;
	opacity: 0.3;
}

'! !

Object subclass: #WAFAQRepository
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideFAQ-Model'!

WAFAQRepository class
	instanceVariableNames: 'default'!

!WAFAQRepository class methodsFor: 'as yet unclassified' stamp: 'mb 8/18/2006 15:23'!
default
	default isNil ifTrue: [default := self new].
	^default.! !

!WAFAQRepository methodsFor: 'constants' stamp: 'mb 8/18/2006 16:00'!
categoryUnclassified
	^self repositoryData categoryUnclassified! !

!WAFAQRepository methodsFor: 'accessing' stamp: 'mb 8/18/2006 16:09'!
contents
	| categories categoryRegistry   |
	categoryRegistry := Dictionary new.
	self index do: [:ea | categoryRegistry at: ea put: Set new].
	self repositoryData findAll do:
		[:faq |
		| category |
		category := faq category ifNil: [self categoryUnclassified].
		(categoryRegistry at: category ifAbsentPut: [Set new]) add: faq].
	categories := self index asOrderedCollection collect:
		[:faqCategory |
		| faqs |
		faqs := categoryRegistry at: faqCategory.
		categoryRegistry removeKey: faqCategory.
		faqCategory -> faqs asSortedCollection].
	categoryRegistry keysAndValuesDo:
		[:faqCategory :faqs |
		categories add: faqCategory -> faqs asSortedCollection].
	^categories! !

!WAFAQRepository methodsFor: 'constants' stamp: 'mb 8/18/2006 16:00'!
index
	^self repositoryData index! !

!WAFAQRepository methodsFor: 'accessing' stamp: 'mb 8/18/2006 15:32'!
repositoryData
	^WAFAQRepositoryData default! !

Object subclass: #WAFAQRepositoryData
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideFAQ-Model'!

!WAFAQRepositoryData class methodsFor: 'constants' stamp: 'mb 8/18/2006 17:13'!
categoryDeployment
	^'Deployment and maintenance'! !

!WAFAQRepositoryData class methodsFor: 'constants' stamp: 'mb 8/18/2006 17:13'!
categoryErrors
	^'Errors and messages'! !

!WAFAQRepositoryData class methodsFor: 'constants' stamp: 'mb 8/18/2006 15:36'!
categoryGeneral
	^'General'! !

!WAFAQRepositoryData class methodsFor: 'constants' stamp: 'mb 8/18/2006 15:39'!
categoryHowTo
	^'How to'! !

!WAFAQRepositoryData class methodsFor: 'constants' stamp: 'mb 8/18/2006 15:58'!
categoryUnclassified
	^'As yet unclassified'! !

!WAFAQRepositoryData class methodsFor: 'constants' stamp: 'mb 8/18/2006 15:38'!
categoryWhat
	^'What/Why'! !

!WAFAQRepositoryData class methodsFor: 'constants' stamp: 'mb 8/18/2006 17:58'!
categoryWhatWrong
	^'What is wrong'! !

!WAFAQRepositoryData class methodsFor: 'singleton' stamp: 'mb 8/18/2006 13:39'!
default
	^self! !

!WAFAQRepositoryData class methodsFor: 'factory' stamp: 'mb 8/18/2006 16:14'!
factory
	^WAFrequentlyAskedQuestion! !

!WAFAQRepositoryData class methodsFor: 'faq general' stamp: 'mb 8/18/2006 15:51'!
faq1
	^self
		id: 1
		question: 'What is Seaside ?'
		category: self categoryGeneral 
		link: 'http://seaside.st'
! !

!WAFAQRepositoryData class methodsFor: 'faq what wrong' stamp: 'mb 8/18/2006 18:09'!
faq10
	^self
		id: 1
		question: 'Nothing happens when I click this link  ?'
		category: self categoryWhatWrong
		title: 'Callback not evaluated with the Canvas api'
		htmlResponse:

'
<p>When the callback attached to an anchor is not evaluated, make sure you check that #with: or #text: is the last message sentto the anchor brush.</p>
<pre style="font-size: 120%">
	(html anchor)
		callback: [self close];
		with:
			[(html image>
				fileName: &quot;closeButton.png&quot;;
				mimeType: &quot;image/png&quot;].
</pre>

'! !

!WAFAQRepositoryData class methodsFor: 'faq general' stamp: 'mb 8/18/2006 15:47'!
faq2
	^self
		id: 2
		question: 'Is Seaside ready for production ?'
		category: self categoryGeneral 
		title: 'Is Seaside production ready'
		response:

'Seaside is used productively for many commercial and non-commercial applications.'! !

!WAFAQRepositoryData class methodsFor: 'faq general' stamp: 'mb 8/18/2006 15:53'!
faq3
	^self
		id: 3
		question: 'Applications built with Seaside'
		category: self categoryGeneral 
		htmlResponse:

'As mentionned in the
<a href="http://lists.squeakfoundation.org/pipermail/seaside/2003-August/001929.html">mailing list</a>.'! !

!WAFAQRepositoryData class methodsFor: 'faq general' stamp: 'mb 8/18/2006 15:54'!
faq4
	^self
		id: 4
		question: 'Where can I find Seaside tutorials ?'
		category: self categoryGeneral 
		htmlResponse:

'A comprehensive list of tutorials can be found on the 
<a href="http://seaside.st/Tutorial/">Seaside tutorials page</a>.'! !

!WAFAQRepositoryData class methodsFor: 'faq general' stamp: 'mb 8/18/2006 16:47'!
faq5
	^self
		id: 5
		question: 'Is Seaside free ? What license does Seaside use ?'
		category: self categoryGeneral
		title: 'Seaside License'
		htmlResponse:

'<p>As of the Seaside 2.5 release (which was beta as of 2004 Jan 08), Seaside has been under the MIT license. This means that you can use it to build commercial apps, royalty free, with no restrictions. Note that, besides Squeak, this also applies to commercial Smalltalks such as VisualWorks and Dolphin Smalltalk.</p>
<p>See more details on the <a href="http://seaside.st/License/">Seaside license page</a>.</p>'! !

!WAFAQRepositoryData class methodsFor: 'faq general' stamp: 'mb 8/18/2006 16:54'!
faq6
	^self
		id: 6
		question: 'How do I get Seaside ?'
		category: self categoryGeneral
		title: 'Seaside Installation'
		htmlResponse:

'<h5>Squeak</h5>

<p>The tutorial <a href="http://beta4.com/seaside2/tutorial.html">A Walk on the Seaside</a> describes the installation procedure. Note that to install KomHttpServer, you need to install KomServices which in turns requires DynamicBindings.</p

<h5>VisualWorks</h5>
<p>Starting with version 7.2.1, Seaside is shipped on the VisualWorks distribution CD.</p>
<p>Seaside can be loaded in the VisualWorks image using the Parcel Manager, section "Application Server" where you should be able to see the SeasideForWebToolkit parcel. There is some installation documentation in the parcel comments.</p>
<p>Seaside can also be loaded from the public Store repository where  either of the following bundles can be loaded :
- SeasideForWebToolkit, or
- SeasideForSwazoo</p>
<p>Usually, loading from the repository may give you a more recent version 
of Seaside, also it gives the choice of loading older versions of Seaside.
Since the repository is used to build the Seaside ports, it is possible
to get an unstable version, therefore it is recommended to load Seaside
from your hard disk using the Parcel Manager, unless you want to experiment
with newer versions of Seaside or if you are using a version of VisualWorks
older than 7.2.1.</p>
<p>After the VisualWorks installation, Seaside is located in the goodies/contributed/Seaside directory. More items can be found in this directory using the File Browser or the Parcel Manager, like an HTML Seaside introductory tutorial and the original Squeak code.</p>
<p>Since VisualWorks 7.3 Seaside comes with even more items that can be found in this directory:</p>
<ul>
<li>SeasideForSwazoo - A parcel for using Seaside with Swazoo rather than WebToolkit. Note: you may load both SeasideForWebToolkit and SeasideForSwazoo in the same image.</li>
<li>SqueakBase - A prerequisite parcel that provides some compatibility with Squeak and that includes all the known Squeak compatibility extensions that could be found in the repository.</li>
<li>SeasideAsync - An optional parcel that adds AJAX capabilities to Seaside.</li>
<li>BonusPack - A bunch of parcels with Seaside examples, Seaside goodies like Adrian Lienhard&quot;s Mewa, Lukas Renggli&quot;s Scriptaculous library, the Web designer tool for manipulating graphic files, CSS stylesheets and Javascripts, plus various optional utility parcels.</li>
</ul>


<h5>Dolphin Smalltalk</h5>

'! !

!WAFAQRepositoryData class methodsFor: 'faq what' stamp: 'mb 8/18/2006 16:56'!
faq7
	^self
		id: 7
		question: 'What is the difference between WAComponent(component) and WATask(task) ?'
		category: self categoryWhat
		title: 'Difference Between Component And Task'
		response:

'Both of them are reusable, embeddable, callable pieces of user interface. A component has state (instance variables), behavior (it may change its state, and it may also choose to display other components with #call:), and appearance (it renders HTML). A Task has only the first two - it doesn''t render any HTML directly, but only through the components it calls. This is useful when what you want to encapsulate/embed/call is purely a process (show this component, then this one, then this one).

The key method for WATask is #go - as soon as a task is displayed, this method will get invoked, and will presumably #call: other components.
'! !

!WAFAQRepositoryData class methodsFor: 'faq deployment' stamp: 'mb 8/18/2006 17:29'!
faq8
	^self
		id: 8
		question: 'How to exclude applications from the Seaside main dispatcher ?'
		category: self categoryDeployment
		title: 'Excluding applications for deployment'
		response:

'Before deploying for production, it is not a bad idea to remove from the Seaside dispatcher all those applications that are not strictly needed. Otherwise, users may accidentally enter the "counter" or the "store" demo applications.

First of all, you will have to explicitely designate those Seaside applications that are deployed. This is achieved by re-implementing the #isDeployed class method in the root component of the deployed applications. By default, this class method answers false, only the dispatcher editor ("config") and the dispatcher navigator ("browse") answer true.

Then ,to remove applications from the Seaside dispatcher, evaluate the following:

WADispatcher default trimForDeployment.

This will remove all those applications that answer false to message #isDeployed.
'! !

!WAFAQRepositoryData class methodsFor: 'faq how to' stamp: 'mb 8/18/2006 17:35'!
faq9
	^self
		id: 9
		question: 'How do I remove the tool bar ?'
		category: self categoryHowTo
		title: 'Removing the tool bar'
		htmlResponse:

'
<p>Set the value of "Deployment Mode" to false using the dispatcher editor ("config").</p>

<p>This can be also done programatically in the #initialize method of the application''s root component.</p>
<pre style="font-size: 120%">
	initialize
		| app |
		app := self registerAsApplication: &quot;app-name&quot;.
		app preferenceAt: #deploymentMode put: true.
</pre>

'! !

!WAFAQRepositoryData class methodsFor: 'finding' stamp: 'mb 8/18/2006 16:14'!
findAll
	^(self class methodDictionary keys select:
		[:selector |
		selector beginsWith: 'faq'])
	collect:
		[:selector |
		self perform: selector].
! !

!WAFAQRepositoryData class methodsFor: 'factory' stamp: 'mb 8/18/2006 15:49'!
id: i question: q category: c htmlResponse: r 
	^self id: i question: q category: c title: nil htmlResponse: r ! !

!WAFAQRepositoryData class methodsFor: 'factory' stamp: 'mb 8/18/2006 15:52'!
id: i question: q category: c link: r 
	^self id: i question: q category: c type: self typeLink title: nil response: r ! !

!WAFAQRepositoryData class methodsFor: 'factory' stamp: 'mb 8/18/2006 15:47'!
id: i question: q category: c response: r 
	^self id: i question: q category: c title: nil response: r ! !

!WAFAQRepositoryData class methodsFor: 'factory' stamp: 'mb 8/18/2006 15:48'!
id: i question: q category: c title: tit htmlResponse: r 
	^self id: i question: q category: c type: self typeHtml title: tit response: r ! !

!WAFAQRepositoryData class methodsFor: 'factory' stamp: 'mb 8/18/2006 15:46'!
id: i question: q category: c title: tit response: r 
	^self id: i question: q category: c type: self typeText title: tit response: r ! !

!WAFAQRepositoryData class methodsFor: 'factory' stamp: 'mb 8/18/2006 15:46'!
id: i question: q category: c type: typ response: r 
	^self id: i question: q category: c type: typ title: nil response: r ! !

!WAFAQRepositoryData class methodsFor: 'factory' stamp: 'mb 8/18/2006 16:13'!
id: i question: q category: c type: typ title: tit response: r 
	^self factory id: i question: q category: c type: typ title: tit response: r ! !

!WAFAQRepositoryData class methodsFor: 'faq index' stamp: 'mb 8/18/2006 17:58'!
index
	"Used to order the categories in the UI"
	^(OrderedCollection new)
		add: self categoryGeneral;
		add: self categoryWhat;
		add: self categoryHowTo;
		add: self categoryWhatWrong;
		add: self categoryDeployment;
		add: self categoryErrors;



		yourself! !

!WAFAQRepositoryData class methodsFor: 'constants' stamp: 'mb 8/18/2006 16:15'!
typeHtml
	"Text with embedded HTML"
	^#html! !

!WAFAQRepositoryData class methodsFor: 'constants' stamp: 'mb 8/18/2006 15:38'!
typeLink
	"Only an URL to foreign web page"
	^#link! !

!WAFAQRepositoryData class methodsFor: 'constants' stamp: 'mb 8/18/2006 15:37'!
typeText
	"Normal text, no embedded HTML"
	^#text! !

Object subclass: #WAFrequentlyAskedQuestion
	instanceVariableNames: 'id question category type title response'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideFAQ-Model'!

!WAFrequentlyAskedQuestion class methodsFor: 'instance creation' stamp: 'mb 8/18/2006 15:32'!
id: i question: q category: c type: typ title: tit response: r
	^self new id: i question: q category: c type: typ title: tit response: r ! !

!WAFrequentlyAskedQuestion methodsFor: 'accessing' stamp: 'mb 8/18/2006 16:27'!
category
	^ category! !

!WAFrequentlyAskedQuestion methodsFor: 'accessing' stamp: 'mb 8/18/2006 13:34'!
id
	^ id! !

!WAFrequentlyAskedQuestion methodsFor: 'accessing' stamp: 'mb 8/18/2006 13:35'!
id: anInteger
	id := anInteger! !

!WAFrequentlyAskedQuestion methodsFor: 'accessing' stamp: 'mb 8/18/2006 16:53'!
id: i question: q category: c type: typ title: tit response: r 
	id := i.
	question := q.
	category := c.
	type := typ.
	title := tit.
	response := r.! !

!WAFrequentlyAskedQuestion methodsFor: 'testing' stamp: 'mb 8/18/2006 13:58'!
isHtml
	^self type = self repository typeHtml! !

!WAFrequentlyAskedQuestion methodsFor: 'testing' stamp: 'mb 8/18/2006 13:58'!
isLink
	^self type = self repository typeLink! !

!WAFrequentlyAskedQuestion methodsFor: 'testing' stamp: 'mb 8/18/2006 13:58'!
isText
	^self type = self repository typeText! !

!WAFrequentlyAskedQuestion methodsFor: 'printing' stamp: 'mb 8/18/2006 13:46'!
printOn: aStream
	aStream
		nextPutAll: 'FAQ #';
		nextPutAll: self id printString! !

!WAFrequentlyAskedQuestion methodsFor: 'accessing' stamp: 'mb 8/18/2006 16:27'!
question
	^question! !

!WAFrequentlyAskedQuestion methodsFor: 'private' stamp: 'mb 8/18/2006 16:20'!
repository
	^WAFAQRepositoryData default! !

!WAFrequentlyAskedQuestion methodsFor: 'accessing' stamp: 'mb 8/18/2006 16:27'!
response
	^ response! !

!WAFrequentlyAskedQuestion methodsFor: 'accessing' stamp: 'mb 8/18/2006 16:27'!
title
	^ title ifNil: [question].! !

!WAFrequentlyAskedQuestion methodsFor: 'accessing' stamp: 'mb 8/18/2006 16:28'!
type
	^ type! !

!WAFrequentlyAskedQuestion methodsFor: 'comparing' stamp: 'mb 8/18/2006 16:20'!
<= another
	^self id <= another id! !
WAFAQ initialize!
